# NOTE on SAT implementations.
# Upstream wants MathSat, which is nonfree and closed source.  We can do
# without the solving capability, or we can look for an alternative:
# - glpk: either solves for floating point numbers or integers, but we need to
#   solve for rational solutions.  Looks infeasible.
# - CVC4: has a rational solver, unknown whether it accepts constraints
# - linbox: has a rational solver, unknown whether it accepts constraints

%define basen cocoa
%define major 0
%define libname %mklibname %{basen} %{major}
%define develname %mklibname %{basen} -d

Name:           cocoalib
Version:        0.99710
Group:          Development/C++
Release:        %mkrel 1
Summary:        C++ library for computations in commutative algebra

License:        GPLv3+
URL:            http://cocoa.dima.unige.it/%{name}/
Source0:        http://cocoa.dima.unige.it/%{name}/tgz/CoCoALib-%{version}.tgz
# Build a shared library instead of a static library
Patch0:         %{name}-shared.patch
# Add a noreturn attribute to silence several warnings
Patch2:         %{name}-noreturn.patch
# Add a missing #include
Patch3:         %{name}-include.patch
# Fix out of bounds vector accesses
Patch4:         %{name}-vec.patch
# Initialize cdd for gfanlib
Patch5:         %{name}-gfanlib.patch

BuildRequires:  boost-devel
BuildRequires:  cddlib-devel
BuildRequires:  cddlib-static
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  gsl-devel
BuildRequires:  java-headless
BuildRequires:  frobby-devel
BuildRequires:  gfan-devel
BuildRequires:  blas-devel
BuildRequires:  lapack-devel
BuildRequires:  readline-devel
BuildRequires:  texlive-texmf
BuildRequires:  txt2tags

%description
The CoCoA C++ library offers functions to perform calculations in
Computational Commutative Algebra, and some other related areas.  The
library is designed to be pleasant to use while offering good run-time
performance.
%package -n %{libname}
Summary:        C++ library for computations in commutative algebra
%description -n %{libname}
The CoCoA C++ library offers functions to perform calculations in
Computational Commutative Algebra, and some other related areas.  The
library is designed to be pleasant to use while offering good run-time
performance.

%package -n %{develname}
Summary:        Headers and library links for %{name}
Requires:       %{libname} = %{version}-%{release}
Requires:       boost-devel
Requires:       gmp-devel
Requires:       gsl-devel
Requires:       gfan-devel
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
Headers and library links for developing applications that use %{name}.

%package doc
Summary:        Documentation for %{name}
License:        GFDL
BuildArch:      noarch

%description doc
Documentation for %{name}.

%prep
%setup -n CoCoALib-%{version}
%patch0 -p1 -b .p0
%patch2 -p0 -b .p2
%patch3 -p0 -b .p3
%patch4 -p0 -b .p4
%patch5 -p0 -b .p5

# Use OpenBlas instead of the reference lapack/blas implementation
# sed -i 's,-lblas -llapack,-lopenblas,' configure

# Lots of files incorrectly have executable permissions.  Remove all such
# permissions, then restore the few that are correct.
find -O3 . -type f -perm /0111 \! -name \*.sh -exec chmod a-x {} \+
chmod a+x configure src/CoCoA-5/cocoa5

# Do not suppress compiler command lines
sed -i 's/\$(MAKE) -s/\$(MAKE)/' Makefile doc/Makefile src/Makefile \
    src/AlgebraicCore/Makefile src/AlgebraicCore/TmpFactorDir/Makefile

%build
%__perl -lp -i -e 's=(CDD_INC_DIR/)cdd"=${1}cddlib"=g' ./configure
# Taken from Fedora rawhide - thanks
sed -i -e 's/ -Wall -pedantic/ $CXXFLAGS/' \
    ./configure

# This is NOT an autoconf-generated configure script!
./configure --prefix=%{_prefix} --threadsafe-hack \
  --with-cxxflags="%{optflags} -fPIC -I%{_includedir}/frobby -I%{_includedir}/gfanlib $RPM_LD_FLAGS" \
  --with-libcddgmp=%{_libdir}/libcddgmp.so \
  --with-libfrobby=%{_libdir}/libfrobby.so \
  --with-libgfan=%{_libdir}/libgfan.so \
  --with-libgsl=%{_libdir}/libgsl.so

# Defeat upstream's attempt to force us to use static libraries
pushd configuration/ExternalLibs/lib
for fil in cddgmp frobby gsl; do
  mv lib${fil}-symlink.so lib${fil}-symlink.a
done
popd

CPATH+=":/usr/include/gfanlib:/usr/include/frobby"
export CPATH
%make_build -j1 library
%make_build -j1 doc

%install
# The Makefile ignores DESTDIR.  Install by hand.

# Install the library
mkdir -p %{buildroot}%{_libdir}
cp -p src/AlgebraicCore/libcocoa.so.0.0.0 %{buildroot}%{_libdir}
ln -s libcocoa.so.0.0.0 %{buildroot}%{_libdir}/libcocoa.so.0
ln -s libcocoa.so.0 %{buildroot}%{_libdir}/libcocoa.so

# Install the headers
mkdir -p %{buildroot}%{_includedir}
cp -a include/CoCoA %{buildroot}%{_includedir}
rm -f %{buildroot}%{_includedir}/{MakeUnifiedHeader.sh,PREPROCESSOR_DEFNS.H-old}

# Remove files from the doc directories that we want to include in %%files
rm -f doc/CoCoALib-tasks/{HTMLTasks,HTMLTasks.C,Makefile,tasks.xml}
rm -f examples/CopyInfo
chmod a-x examples/*.sh

%check
# 32-bit systems are unable to pass some of the tests due to the limited range
# of the FFelem type.  Disable those tests.
if [ "%{__isa_bits}" = "32" ]; then
  sed -e '/test-factor1\.C/d' \
      -e 's/test-SparsePolyRing1\.C //' \
      -e 's/test-SparsePolyRing5\.C //' \
      -e '/test-SqFreeFactor1\.C/d' \
      -i src/tests/Makefile
fi

export LD_LIBRARY_PATH=$PWD/lib
make check

%files -n %{libname}
%license COPYING-GPLv3
%doc README
%{_libdir}/libcocoa.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/CoCoA
%{_libdir}/libcocoa.so

%files doc
%license doc/COPYING
%doc doc/*.html
%doc doc/*.pdf
%doc doc/CoCoALib-tasks
%doc doc/html
%doc examples



%changelog
* Fri Sep 25 2020 shlomif <shlomif> 0.99710-1.mga8
+ Revision: 1629980
- New version 0.99710

* Sun Feb 16 2020 umeabot <umeabot> 0.99601-3.mga8
+ Revision: 1529690
- Mageia 8 Mass Rebuild

* Tue Aug 27 2019 daviddavid <daviddavid> 0.99601-2.mga8
+ Revision: 1433759
- rebuild for new gsl 2.6

* Fri Mar 15 2019 shlomif <shlomif> 0.99601-1.mga7
+ Revision: 1377650
- New version - thanks to fedora

* Sun Mar 10 2019 shlomif <shlomif> 0.99600-1.mga7
+ Revision: 1373616
- made the .spec more mageia-like
- import from fedora

